@@ -457,7 +457,6 @@ class VariableClUpdateSettingsChangesSet(Variable):
         old_portage_state_hash = ini.getVar('system', 'portage_hash') or ""
         ps = PortageState()
         new_portage_state_hash = ps.get_state()
-        a = new_portage_state_hash != old_portage_state_hash
         return "on" if new_portage_state_hash != old_portage_state_hash else "off"
 
 
@@ -1882,11 +1881,16 @@ class VariableClUpdatePackageCacheSet(Variable):
     Необходимость обновить Packages
     """
     type = "bool"
+    value = ''
 
     def get(self):
+        if self.value:
+            return self.value
         packages_fn = self.Get('cl_update_package_cache')
         gpg = self.Get('cl_update_gpg')
         packages_asc_fn = self.Get('cl_update_package_cache_sign')
+        a = path.exists(packages_fn)
+        b = path.exists(packages_asc_fn)
         if (not path.exists(packages_fn) or
             gpg and not path.exists(packages_asc_fn)):
             return "on"
